@@ -32,7 +32,7 @@ START_TEST(test_basic)
     fail_unless(OSINFO_IS_LOADER(loader), "Loader is not a LOADER");
 
     GError *error = NULL;
-    osinfo_loader_process_path(loader, SRCDIR "/data", &error);
+    osinfo_loader_process_default_path(loader, &error);
     fail_unless(error == NULL, error ? error->message : "none");
 
     g_object_unref(loader);
