@@ -26,8 +26,6 @@
 #include <osinfo/osinfo.h>
 #include <check.h>
 #include <libsoup/soup.h>
-#define HAVE_LIBSOUP_GNOME
-#include <libsoup/soup-gnome.h>
 
 static void test_media(OsinfoMediaList *medialist, GError **error, SoupSession *session)
 {
@@ -68,11 +66,8 @@ START_TEST(test_uris)
     GList *osel = NULL, *tmp;
     const gchar *debugstr;
 
-    session = soup_session_async_new_with_options(
-#ifdef HAVE_LIBSOUP_GNOME
-                                                  SOUP_SESSION_ADD_FEATURE_BY_TYPE,
-#endif
-                                                  NULL);
+    session = soup_session_new();
+
     if ((debugstr = g_getenv("LIBOSINFO_TEST_DEBUG"))) {
         SoupLogger *logger;
         int debug_level = atoi(debugstr);
@@ -102,7 +97,7 @@ START_TEST(test_uris)
         tmp = tmp->next;
     }
 
-    g_list_free(tmp);
+    g_list_free(osel);
     if (oslist)
         g_object_unref(oslist);
 
@@ -130,13 +125,12 @@ int main(void)
     Suite *s = list_suite();
     SRunner *sr = srunner_create(s);
 
+    /* Make sure we catch unexpected g_warning() */
+    g_log_set_always_fatal(G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING);
+
     if (!g_getenv("LIBOSINFO_NETWORK_TESTS"))
         return 77; /* Skip */
 
-#if !GLIB_CHECK_VERSION(2,35,1)
-    g_type_init();
-#endif
-
     /* Upfront so we don't confuse valgrind */
     osinfo_entity_get_type();
     osinfo_db_get_type();
