@@ -72,7 +72,7 @@ START_TEST(test_loader)
     const char *str;
 
     loader = osinfo_loader_new();
-    osinfo_loader_process_path(loader, SRCDIR "/test/test-os.xml", &error);
+    osinfo_loader_process_path(loader, SRCDIR "/test/dbdata", &error);
     fail_unless(error == NULL, error ? error->message:"none");
     db = osinfo_loader_get_db(loader);
 
@@ -124,6 +124,9 @@ START_TEST(test_loader)
     fail_unless(os != NULL, "could not find OS 'test5'");
     str = osinfo_product_get_short_id(OSINFO_PRODUCT(os));
     fail_unless(g_strcmp0(str, "test5") == 0, "wrong OS short-id");
+    /* 'test5' OS intentionnally contains an invalid release status */
+    g_test_expect_message(NULL, G_LOG_LEVEL_CRITICAL,
+                          "*(osinfo_entity_get_param_value_enum): should not be reached*");
     fail_unless(osinfo_os_get_release_status(os) == OSINFO_RELEASE_STATUS_RELEASED,
                 "OS should be a released one");
 
@@ -213,9 +216,8 @@ int main(void)
     Suite *s = os_suite();
     SRunner *sr = srunner_create(s);
 
-#if !GLIB_CHECK_VERSION(2,35,1)
-    g_type_init();
-#endif
+    /* Make sure we catch unexpected g_warning() */
+    g_log_set_always_fatal(G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING);
 
     /* Upfront so we don't confuse valgrind */
     osinfo_platform_get_type();
